@@ -2,12 +2,9 @@
   if (is.null(x)) y else x
 }
 
-is_installed <- function(pkg) {
-  isTRUE(requireNamespace(pkg, quietly = TRUE))
-}
-
 as_tibble <- function(x) {
-  if (getOption("worldbank.use_tibble", TRUE) && is_installed("tibble")) {
+  if (getOption("worldbank.use_tibble", TRUE) &&
+    requireNamespace("tibble", quietly = TRUE)) {
     tibble::as_tibble(x)
   } else {
     x
